@@ -70,6 +70,7 @@ class CRSDHeaderBase(object):
     _required = ()
 
     def __init__(self, **kwargs):
+        # abstract class
         pass
 
     @classmethod
@@ -290,7 +291,7 @@ class CRSDType(Serializable):
             for el in GeoInfo:
                 self.addGeoInfo(el)
         else:
-            raise ('GeoInfo got unexpected type {}'.format(type(GeoInfo)))
+            raise ValueError('GeoInfo got unexpected type {}'.format(type(GeoInfo)))
 
         super(CRSDType, self).__init__(**kwargs)
 
